@@ -11,7 +11,7 @@ use Test2::Mock();
 
 use base 'Exporter';
 
-our $VERSION = '0.000102';
+our $VERSION = '0.000118';
 
 our @CARP_NOT = (__PACKAGE__, 'Test2::Mock');
 our @EXPORT = qw/mock mocked/;
@@ -314,6 +314,9 @@ plugins in ways L<Mock::Quick> would be unable to.
         override => [
             replace_method => sub { ... },
         ],
+        set => [
+            replace_or_inject => sub { ... },
+        ]
     );
 
     Some::Class->new_method();        # Calls the newly injected method
@@ -523,7 +526,7 @@ F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 COPYRIGHT
 
-Copyright 2017 Chad Granum E<lt>exodist@cpan.orgE<gt>.
+Copyright 2018 Chad Granum E<lt>exodist@cpan.orgE<gt>.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
